==> generator-hyperledger-composer-network-0.1.1.tgz: package/README.md <==
Chevdor, &lt;<chevdor@gmail.com>&gt; v0.1, 2014-08-24 :idprefix:
:idseparator: - :experimental: :endash:

First look
==========

![](https://asciinema.org/a/89762.png)

Getting Started
===============

What is this generator about?
-----------------------------

**hyperledger-composer-network** is all about getting started quickly.
Running this generator will build a simple dapp for Ethereum. Better
than just a boilerplate, the generated file is already tuned with your
name, etc…

Read on a give a try.

What is Yeoman?
---------------

Trick question. It’s not a thing. It’s this guy:

![](http://i.imgur.com/JHaAlBJ.png)

Basically, he wears a top hat, lives in your computer, and waits for you
to tell him what kind of application you wish to create.

Not every new computer comes with a Yeoman pre-installed. He lives in
the \[npm\](<https://npmjs.org>) package repository. You only have to
ask for him once, then he packs up and moves into your hard drive.
**Make sure you clean up, he likes new and shiny things.**

\`\`\`bash npm install -g yo \`\`\`

Yeoman Generators
-----------------

Yeoman travels light. He didn’t pack any generators when he moved in.
You can think of a generator like a plug-in. You get to choose what type
of application you wish to create, such as a Backbone application or
even a Chrome extension.

To install hyperledger-composer-network from npm, run:

\`\`\`bash npm install -g hyperledger-composer-network \`\`\`

Finally, initiate the generator:

\`\`\`bash yo hyperledger-composer-network \`\`\`

Getting To Know Yeoman
----------------------

Yeoman has a heart of gold. He’s a person with feelings and opinions,
but he’s very easy to work with. If you think he’s too opinionated, he
can be easily convinced.

If you’d like to get to know Yeoman better and meet some of his friends,
\[Grunt\](<http://gruntjs.com>) and \[Bower\](<http://bower.io>), check
out the complete \[Getting Started
Guide\](<https://github.com/yeoman/yeoman/wiki/Getting-Started>).

Generating your Network
=======================

\`\`\`bash yo hyperledger-composer-network \`\`\`

License
=======

MIT

==> generator-hyperledger-composer-network-0.1.6.tgz: package/README.md <==
\# Hyperledger Composer Network Generator Chevdor,
&lt;<chevdor@gmail.com>&gt; v0.1, 2014-08-24 :idprefix: :idseparator: -
:experimental: :endash:

First look
==========

![](https://asciinema.org/a/89762.png)

Getting Started
===============

What is this generator about?
-----------------------------

**hyperledger-composer-network** is all about getting started quickly.
Running this generator will build a simple network for Hyperledger
Composer. Better than just a boilerplate, the generated file is already
tuned with your name, etc…

Read on a give a try.

What is Yeoman?
---------------

Trick question. It’s not a thing. It’s this guy:

![](http://i.imgur.com/JHaAlBJ.png)

Basically, he wears a top hat, lives in your computer, and waits for you
to tell him what kind of application you wish to create.

Not every new computer comes with a Yeoman pre-installed. He lives in
the \[npm\](<https://npmjs.org>) package repository. You only have to
ask for him once, then he packs up and moves into your hard drive.
**Make sure you clean up, he likes new and shiny things.**

\`\`\`bash npm install -g yo \`\`\`

Yeoman Generators
-----------------

Yeoman travels light. He didn’t pack any generators when he moved in.
You can think of a generator like a plug-in. You get to choose what type
of application you wish to create, such as a Backbone application or
even a Chrome extension.

To install hyperledger-composer-network from npm, run:

\`\`\`bash npm install -g hyperledger-composer-network \`\`\`

Finally, initiate the generator:

\`\`\`bash yo hyperledger-composer-network \`\`\`

Getting To Know Yeoman
----------------------

Yeoman has a heart of gold. He’s a person with feelings and opinions,
but he’s very easy to work with. If you think he’s too opinionated, he
can be easily convinced.

If you’d like to get to know Yeoman better and meet some of his friends,
\[Grunt\](<http://gruntjs.com>) and \[Bower\](<http://bower.io>), check
out the complete \[Getting Started
Guide\](<https://github.com/yeoman/yeoman/wiki/Getting-Started>).

Generating your Network
=======================

\`\`\`bash yo hyperledger-composer-network \`\`\`

License
=======

MIT
